//////////////////////////////////////////////////////////////////////////////////////////////
// Clase para resolver un sistema lineal mediante Jacobi                                    //
//                                                                                          //
// Anlisis y Diseo y Programacin:                                                        //
//                                                                                          //
// Nombre:   Antonio Carrillo Ledesma                                                       //
// E-mail:   acl@www.mmc.igeofcu.unam.mx                                                    //
// Pgina:   http://www.mmc.igeofcu.unam.mx/acl                                             //
//                                                                                          //
//                                                                                          //
// Este programa es software libre. Puede redistribuirlo y/o modificarlo                    //
// bajo los trminos de la Licencia Pblica General de GNU segn es                         //
// publicada por la Free Software Foundation, bien de la versin 2 de                       //
// dicha Licencia o bien (segn su eleccin) de cualquier versin                           //
// posterior.                                                                               //
//                                                                                          //
// Este programa se distribuye con la esperanza de que sea til, pero SIN                   //
// NINGUNA GARANTA, incluso sin la garanta MERCANTIL implcita o sin                      //
// garantizar la CONVENIENCIA PARA UN PROPSITO PARTICULAR. Vase la                        //
// Licencia Pblica General de GNU para ms detalles.                                       //
//                                                                                          //
// Debera haber recibido una copia de la Licencia Pblica General junto                    //
// con este programa. Si no ha sido as, escriba a la Free Software                         //
// Foundation, Inc., en 675 Mass Ave, Cambridge, MA 02139, EEUU.                            //
//                                                                                          //
//                                                                                          //
//////////////////////////////////////////////////////////////////////////////////////////////



#ifndef __ResuelveJacobi__
#define __ResuelveJacobi__

#include "ResuelveSistemaLineal.hpp"
#include "MatrizBandDisp.hpp"


/// Clase para resolucin del sistema lineal mediante Jacobi
/** @author Antonio Carrillo Ledesma
    @date primavera 2009
    @version 1.0.1
    @bug No hay errores conocidos
*/
class ResuelveJacobi: public ResuelveSistemaLineal
{

protected:

   /// Tolerancia
   ldouble Ep;
   /// Iteraciones mximas
   int Iter;


public:


   /// Constructor de la clase
   ResuelveJacobi(void) : ResuelveSistemaLineal()
   {
      X = NULL;
      B = NULL;
      Ep = 1e-5;
      Iter = 1000;
      MetodoModificaMatriz = false;
      MetodoNumerico = JACOBI;
   }

   /// Constructor de la clase
   /** @param x Puntero a un Vector, solucin del sistema lineal
       @param b Puntero a un vector, lado derecho del sistema lineal */
   ResuelveJacobi(Vector *x, Vector *b) : ResuelveSistemaLineal()
   {
      X = x;
      B = b;
      Ep = 1e-5;
      Iter = 1000;
      MetodoModificaMatriz = false;
      MetodoNumerico = JACOBI;
   }

   /// Constructor de la clase
   /** @param x Puntero a un Vector, solucin del sistema lineal
       @param b Puntero a un vector, lado derecho del sistema lineal
       @param ep Tolerancia del mtodo
       @param iter Nmero mximo de iteraciones */
   ResuelveJacobi(Vector *x, Vector *b, ldouble ep, int iter) : ResuelveSistemaLineal()
   {
      X = x;
      B = b;
      Ep = ep;
      Iter = iter;
      MetodoModificaMatriz = false;
      MetodoNumerico = JACOBI;
   }

};

#endif
